#
# spec file for package aws-crt-cpp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_soversion 1

Name:           aws-crt-cpp
Version:        0.32.4
Release:        1.1
Summary:        AWS C++ wrapper for AWS SDK C libraries
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://aws.amazon.com/sdk-for-cpp/
Source0:        https://github.com/awslabs/aws-crt-cpp/archive/v%{version}.tar.gz
Patch0:         acc_add-so-version.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  cmake(aws-c-auth)
BuildRequires:  cmake(aws-c-cal)
BuildRequires:  cmake(aws-c-common)
BuildRequires:  cmake(aws-c-compression)
BuildRequires:  cmake(aws-c-event-stream)
BuildRequires:  cmake(aws-c-http)
BuildRequires:  cmake(aws-c-io)
BuildRequires:  cmake(aws-c-mqtt)
BuildRequires:  cmake(aws-c-s3)
BuildRequires:  cmake(aws-c-sdkutils)
BuildRequires:  cmake(aws-checksums)
BuildRequires:  cmake(s2n)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(zlib)

%description
The AWS SDK for C++ provides a modern C++ (version C++ 11 or later) interface for
Amazon Web Services (AWS). It is meant to be performant and fully functioning with
low- and high-level SDKs, while minimizing dependencies and providing platform
portability (Windows, OSX, Linux, and mobile).

%package bin
Summary:        AWS C++ wrapper for AWS SDK C libraries - application binaries
Group:          Development/Languages/Other

%description bin
AWS C++ wrapper for the following AWS SDK C libraries

 * aws-c-common: Cross-platform primitives and data structures.
 * aws-c-io: Cross-platform event-loops, non-blocking I/O, and TLS implementations.
 * aws-c-mqtt: MQTT client.
 * aws-c-auth: Auth signers such as Aws-auth sigv4
 * aws-c-http: HTTP 1.1 client, and websockets (H2 coming soon)
 * aws-checksums: Cross-Platform HW accelerated CRC32c and CRC32 with fallback to efficient SW implementations.
 * aws-c-event-stream: C99 implementation of the vnd.amazon.event-stream content-type.

This package contains application binaries.

%package -n lib%{name}%{library_soversion}
Summary:        AWS C++ wrapper for AWS SDK C libraries
Group:          Development/Languages/Other

%description -n lib%{name}%{library_soversion}
AWS C++ wrapper for the following AWS SDK C libraries

 * aws-c-common: Cross-platform primitives and data structures.
 * aws-c-io: Cross-platform event-loops, non-blocking I/O, and TLS implementations.
 * aws-c-mqtt: MQTT client.
 * aws-c-auth: Auth signers such as Aws-auth sigv4
 * aws-c-http: HTTP 1.1 client, and websockets (H2 coming soon)
 * aws-checksums: Cross-Platform HW accelerated CRC32c and CRC32 with fallback to efficient SW implementations.
 * aws-c-event-stream: C99 implementation of the vnd.amazon.event-stream content-type.

This package contains the shared libraries.

%package devel
Summary:        AWS C++ wrapper for AWS SDK C libraries - development files
Group:          Development/Languages/Other
Requires:       lib%{name}%{library_soversion} = %{version}

%description devel
AWS C++ wrapper for the following AWS SDK C libraries

 * aws-c-common: Cross-platform primitives and data structures.
 * aws-c-io: Cross-platform event-loops, non-blocking I/O, and TLS implementations.
 * aws-c-mqtt: MQTT client.
 * aws-c-auth: Auth signers such as Aws-auth sigv4
 * aws-c-http: HTTP 1.1 client, and websockets (H2 coming soon)
 * aws-checksums: Cross-Platform HW accelerated CRC32c and CRC32 with fallback to efficient SW implementations.
 * aws-c-event-stream: C99 implementation of the vnd.amazon.event-stream content-type.

This package contains development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DBUILD_DEPS=OFF \
    -DCMAKE_MODULE_PATH=%{_libdir}/cmake
%cmake_build

%install
%cmake_install
%fdupes -s %{buildroot}%{_libdir}/cmake

# Testsuite requires network connection
#%%check
#%%ctest

%ldconfig_scriptlets -n lib%{name}%{library_soversion}

%files bin
%{_bindir}/*

%files -n lib%{name}%{library_soversion}
%doc README.md
%{_libdir}/*.so.%{library_soversion}
%{_libdir}/*.so.%{library_version}

%files devel
%{_includedir}/aws
%{_libdir}/*.so
%{_libdir}/cmake

%changelog
* Tue Apr 15 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.32.4
  * Bump crt checksums by @DmitriyMusatkin in (#730)
* Mon Apr  7 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.32.3
  * Fix assignment operator in Optional by @sfod in (#720)
  * Fix clang error in string view by @sbiscigl in (#728)
- from version 0.32.2
  * Revert checksums header install location change
    by @DmitriyMusatkin in (#726)
- from version 0.31.2
  * Fix flaky CBOR test by @graebm in (#718)
  * Use latest PQ TLS Cipher Preference in Tests by @alexw91 in (#717)
  * Fix "std-compat" CI to actually test what it's supposed to
    by @graebm in (#719)
  * Fix IP address being labelled "bad" for too long by @graebm in (#723)
  * Initialize checksums explicitly by @DmitriyMusatkin in (#722)
* Tue Mar 18 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.31.1
  * Fix ARM-based CI steps by @DmitriyMusatkin in (#713)
  * HTTP/1: Support streaming requests of unknown length
    by @graebm in (#714)
* Thu Feb 27 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.31.0
  * Update submodules by @sfod in (#711)
- from version 0.30.2
  * Support IPv6 endpoint by @sbera87 in (#707)
- Add patch to add missing SOVERSION to CMakeFiles.txt
  * acc_add-so-version.patch
- Add %%{_libdir}/*.so.%%{library_soversion} to %%files section
- Add %%{_libdir}/*.so.%%{library_version} to %%files section
- Run %%ldconfig_scriptlets in %%install section
* Thu Feb  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.30.1
  * Temporarily rollback s2n by @DmitriyMusatkin in (#705)
- from version 0.30.0
  * Add topic argument to publish callback in request-response
    stream client by @sfod in (#703)
  * CMake modules by @sfod in #702
- from version 0.29.10
  * Fix segfaults -- CRC64NVME on machines with disabled
    AVX and uri parsing corner case. by @TingDaoK in (#700)
- Drop acc_fix-cmake-modules-path.patch, fixed upstream
* Thu Jan 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.9
  * Flaky test pass1 by @bretambrose in (#693)
  * Latest submodules copy_source_uri Change by @waahm7 in (#696)
* Tue Jan  7 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.8
  * Update CRT dependencies by @sfod in (#692)
* Mon Dec  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.7
  * Switch CI to using roles by @DmitriyMusatkin in (#688)
  * Bump crt deps by @DmitriyMusatkin in (#689)
* Wed Dec  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.6
  * Fix crash when building with _GLIBCXX_USE_CXX11_ABI=0 by @graebm in (#686)
* Thu Nov 21 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.5
  * Update submodule by @xiazhvera in (#684)
- from version 0.29.4
  * Request response workspace by @bretambrose in (#664)
* Tue Nov 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.3
  * Fix checksum install location by @sbiscigl in (#680)
- from version 0.29.2
  * Stop building s2n via aws_prebuild_dependency()
    by @graebm in (#677)
- from version 0.29.1
  * chore: Modified bug issue template to add checkbox to
    report potential regression. by @ashishdhingra in (#661)
  * Fix s2n cleanup by @graebm in (#672)
  * Use S2N-TLS v1.5.7 by @graebm in (#673)
  * Fix crashes in GCC 4.x shared-libs builds, due to
    recent symbol visibility changes by @graebm in (#675)
* Thu Oct 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.29.0
  * Update CMake to 3.9 by @waahm7 in (#666)
- from version 0.28.5
  * Latest submodules by @waahm7 in (#668)
- from version 0.28.4
  * Prebuild aws-lc by @sfod in (#648)
  * Prebuild s2n by @TingDaoK in (#665)
* Tue Sep 17 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.28.3
  * Bind out CRC64 by @DmitriyMusatkin in (#662)
* Mon Sep  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.28.2
  * Fix MSVC most vexing parse by @sbiscigl in (#659)
  * Add wrappers around readsome and peek methods in
    std istream by @SergeyRyabinin in (#658)
- from version 0.28.1
  * Fix typo in variant by @sbiscigl in (#653)
  * Fix OpenSSL Compile and Runtime Version Mismatch by @waahm7 in (#656)
- from version 0.28.0
  * Expose socket options from Mqtt5ClientBuilder by @xiazhvera in (#652)
* Mon Aug 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.6
  * Proxy fix by @bretambrose in (#647)
  * Update submodules by @sfod in (#649)
  * Add support for string array ep context
    params by @DmitriyMusatkin in (#646)
  * Fix websocket shutdown behavior
    (submodule updates) by @graebm in (#650)
* Wed Aug  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.5
  * Update MacOS to arm64 by @waahm7 in (#641)
* Fri Jul 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.4
  * Bump crt lib versions by @DmitriyMusatkin in (#639)
* Mon Jul 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.3
  * Fix memory leaks in Windows TLS handler by @graebm in (#637)
* Thu Jul  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.2
  * Make variant index casts more explicit by @DmitriyMusatkin in (#635)
* Wed Jun 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.27.1
  * cbor binding by @TingDaoK in (#627)
  * Fix ASan report about alloc/dealloc mismatch
    when compiled with C++23 by @waahm7 in (#633)
- from version 0.27.0
  * clang-format 18 by @graebm in (#628)
  * Update aes interface by @DmitriyMusatkin in (#631)
* Thu Jun 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.12.
  * Fix bug where last few bytes on socket go unread by @graebm in (#624)
* Tue Jun  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.11
  * Latest submodules by @waahm7 in (#621)
- from version 0.26.10
  * Fix memory leak when UnsubscribePacket is reused by @sfod in (#617)
  * Fix order of arguments when calling aws_aes_gcm_256_new by @sbiscigl in (#618)
  * Symmetric cipher state by @sbiscigl in (#619)
  * AutoTag PR for v0.26.9 by @bretambrose in (#620)
* Wed May 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.9
  - Fix memory leak when UnsubscribePacket is reused by @sfod in (#617)
  - Fix order of arguments when calling aws_aes_gcm_256_new by @sbiscigl in (#618)
  - Symmetric cipher state by @sbiscigl in (#619)
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Mon Apr 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.8
  * Bump s2n version to v1.4.11 to support ecdsa521p
    with TLS1.3 by @alfred2g in (#614)
- from version 0.26.7
  * Updated crypto bindings to include SHA1 and AES for
    use in C++ SDK by @JonathanHenson in (#470)
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.6
  * Disable jekyll on gh-pages by @sfod in (#608)
  * Bump cal by @DmitriyMusatkin in (#611)
- from version 0.26.5
  * CRT version bump by @DmitriyMusatkin in (#609)
* Thu Mar 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.4
  * Basic version of variant type using C++11 by @SergeyRyabinin in (#599)
- from version 0.26.3
  * Add in-place constructor and emplace method
    to optional by @SergeyRyabinin in (#600)
  * Latest submodules by @sbSteveK in (#601)
* Mon Feb 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.2
  * Temporary disable windows cert store test by @xiazhvera in (#595)
  * Update builder to fix CI (v0.9.56) by @xiazhvera in (#596)
  * Update version of s2n and c-cal by @sbiscigl in (#597)
* Tue Jan 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.1
  * Update aws-c-io to pull in channel setup callback
    safety update by @bretambrose in (#591)
* Wed Jan  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.0
  * Change `port` from uint16_t to uint32_t to support VSOCK by @graebm in (#583)
- from version 0.25.1
  * Custom auth polish by @bretambrose in (#584)
  * Test Shared Subscription by @alfred2g in (#587)
  * Fix overridden timeout values for mqtt5 operations by @sfod in (#588)
- from version 0.25.0
  * MQTT5 General Avalibility by @xiazhvera in (#585)
* Wed Dec 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.24.11
  * Version bump to pickup endpoint resolution partition
    changes by @DmitriyMusatkin in (#581)
- from version 0.24.10
  * MQTT5 canary fix by @xiazhvera in (#572)
  * MQTT5 GA API review by @xiazhvera in (#575)
  * Fix host resolve on a non-existent host by @SergeyRyabinin in (#578)
  * Add a method to report library version from ApiHandle by @SergeyRyabinin in (#579)
* Thu Nov 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.24.9
  * Pick up fix for s3express create session hang by @TingDaoK in (#576)
- from version 0.24.8
  * MQTT5 Topic aliasing support by @bretambrose in (#567)
  * Bind missing negotiated setting fields by @bretambrose in (#569)
  * Fix MQTT5 canary memory leak by @sfod in (#570)
  * MQTT5 Canary Improvment by @xiazhvera in (#571)
  * Pick up submodules update for performance optimization
    updates by @TingDaoK in (#573)
* Tue Nov 21 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.24.7
  * Latest Submodules by @waahm7 in (#565)
- from version 0.24.6
  * Fix WSL by @waahm7 in (#563)
- from version 0.24.5
  * Unit test for removing callback severance on 5-to-3
    adapter by @xiazhvera in (#553)
  * Generate files in build directory by @sfod in (#559)
  * Update submodules to pull aws-lc build fix by @sfod in (#560)
- Refresh patches for new version
  * acc_fix-cmake-modules-path.patch
* Tue Oct 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.24.4
  * Update submodules to pick up fix for Sigv4A on MacOS 14+ by @TingDaoK in (#554)
* Fri Oct  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.24.2
  * Fix CMake error when BUILD_DEPS=OFF by @graebm in (#551)
- from version 0.24.1
  * Disable doxygen for private header API by @xiazhvera in (#549)
- from version 0.24.0
  * MQTT3 clean shutdown by @sfod in (#535)
  * Add CI job with sanitizers enabled by @sfod in (#522)
  * Enable PKCS11 tests by @sfod in (#544)
  * Add Mqtt5ClientBuilder method to set bootstrap by @gqmelo in (#542)
  * Fix typo on NegotiatedSettings (Avaliable->Available) by @gqmelo in (#543)
  * Adapter API Update by @xiazhvera in (#545)
  * AutoTag PR for v0.24 by @bretambrose in (#546)
* Tue Sep 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.23.1
  * Added workflow for handling answerable discussions
    by @yasminetalby in (#533)
  * Update mqtt submodule to provide on_connection_termination
    callback by @sfod in (#534)
  * Fix failing CI tests by @sfod in (#536)
  * Fix CMake option for choosing MSVC runtime
    library by @graebm in (#537)
* Tue Aug 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.23.0
  * Fix permissions for stale issue bot by @jmklix (#530)
  * MQTT3 and MQTT5 fixes and updates by @bretambrose (#531)
* Tue Aug 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.22.0
  * Bind out the MQTT5 to MQTT3 adapter by @xiazhvera in (#528)
* Tue Aug  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.21.0
  * Update MQTT submodule to fix decoding/framing issue by @bretambrose in (#525)
- from version 0.20.6
  * Fix format specifier in canary by @xiazhvera in (#521)
  * Treat empty AWS environment variables as unset by @graebm in (#523)
* Tue Jul 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.20.6
  * Use ubuntu-22.04 in CI by @graebm in (#519)
- from version 0.20.5
  * Use Github actions/checkout@v3 by @graebm in (#516)
- from version 0.20.4
  * Use on_connection_* callbacks from aws-c-mqtt by @sfod in (#511)
  * Change S2N security policy for 0-RTT in TLS 1.3. by @graebm in (#514)
  * Fix warnings in headers by @waahm7 in (#500)
* Thu Jul  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.20.3
  * Fix JsonObject rvalue bug by @graebm in (#506)
  * MQTT311 extra connection callbacks by @TwistedTwigleg in (#469)
  * Submodules update by @TingDaoK in (#509)
* Tue May 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.20.2
  * Wrong optional was queried. by @beat-schaer in (#498)
  * Update time to ancient by @jmklix in (#501)
  * Additional unit-tests and unit-test adjustment by @TwistedTwigleg in (#499)
  * Bump the MQTT5 canary builder version by @TwistedTwigleg in (#502)
  * Update submodules by @sbSteveK in (#503)
* Thu May  4 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.20.1
  * Add token key name and value parameters. Add more
    logging by @TwistedTwigleg in (#492)
  * Full backwards compat with custom auth in MQTT311
    by @TwistedTwigleg in (#494)
  * PKCS12 builder support by @TwistedTwigleg in (#493)
  * Update Submodules by @sbSteveK in (#496)
- from version 0.20.0
  * Add GitHub templates and bots by @jmklix in (#488)
  * Mqtt5Client Clean Shutdown Refactor by @xiazhvera in (#485)
  * Capitalize MQTT5 function name by @xiazhvera in (#486)
  * MQTT5 Canary by @xiazhvera in (#443)
  * Enable MQTT5 client unit tests in CI and improve MQTT5
    client error handling by @xiazhvera in (#489)
* Tue Apr 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.9
  * Add sigv4a tests by @sbSteveK in (#472)
  * Add the main page to the documentation by @TwistedTwigleg in (#477)
  * Fix compiler warnings in tests by @graebm in (#476)
  * Remove CJSON and use aws-c-common JSON instead
    by @TwistedTwigleg in (#460)
  * Submodule update to pull in DNS resolution frequency update
    by @bretambrose in (#483)
* Mon Mar  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.8
  * [Aws::Crt::Optional] avoid std::aligned_storage by @kedartal in (#462)
  * Fix ambiguity around InputStream::ReadImpl() errors by @graebm in (#468)
  * Alpine/Musl CI by @bretambrose in (#416)
  * Change #if _MSC_VER to #ifdef _MSC_VER by @graebm in (#473)
* Mon Feb  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.7
  * Update aws-c-auth by @waahm7 in (#465)
- from version 0.19.6
  * Fixing a low severity issue with parsing certificate
    Common Name (CN) by @waahm7 in (#463)
- from version 0.19.5
  * MQTT311 operation statistics support by @TwistedTwigleg in (#455)
* Thu Jan 26 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.4
  * Fix compiler warnings by @waahm7 in (#458)
* Wed Jan 25 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.3
  * Submodules update by @TingDaoK in (#456)
* Mon Jan 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.2
  * Fix GCC/Clang ASM error by @graebm in (#444)
  * Bound strlen call by maximum topic length by @bretambrose in (#446)
  * Custom auth websocket fix by @TwistedTwigleg in (#418)
  * Rejoin always by @bretambrose in (#447)
  * Mqtt5 Interruption tests by @xiazhvera in (#448)
  * Update submodules by @TwistedTwigleg in (#449)
  * Fix flaky tests by @graebm in (#451)
  * How to use system installation of libcrypto by @graebm in (#450)
* Tue Dec  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.19.1
  * Fixes double free bug in destruct http message
- from version 0.19.0
  * Bump sdkutils version by @DmitriyMusatkin in (#436)
  * Mqtt5 Support by @xiazhvera in (#437)
* Fri Nov 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.18.16
  * Change sprintf to snprintf by @jmklix in (#431)
  * Add Support for choosing PQ TLS Cipher Preferences by @alexw91 in (#434)
* Tue Nov 15 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.18.15
  * Remove another unused varaible by @DmitriyMusatkin in (#432)
- from version 0.18.14
  * Fix build warning on Windows by @DmitriyMusatkin in (#429)
* Mon Nov 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing dependency on runtime library package for devel package
* Fri Nov 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.18.13
  * Fix C++ One Definition Rule (ODR) Violations by @graebm in (#426)
- from version 0.18.12
  * Fixed missing new header in the installation destination
- from version 0.18.11
  * Update aws-c-sdkutils to v0.1.6
- from version 0.18.10
  * Added Raspberry support for Github Action by @xiazhvera in (#415)
  * Endpoint resolution engine bindings by @DmitriyMusatkin in (#419)
  * Remove unused variable by @DmitriyMusatkin in (#420)
- from version 0.18.9
  * Version fix by @TingDaoK in (#412)
* Wed Oct  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.18.8
  * Cognito provider by @bretambrose in (#409)
  * Submodule update to pull in event stream
    rpc race fix by @bretambrose in (#413)
- from version 0.18.7
  * S2N v1.3.22 by @graebm in (#410)
- from version 0.18.6
  * Update aws-c-s3 for endpoints race-condition fix by @graebm in (#405)
  * Allow static and shared libs to be mixed by @TingDaoK in (#396)
- from version 0.18.5
  * Updates AWS-C-IO & AWS-C-S3 by @waahm7 in (#403)
- from version 0.18.4
  * Fix typo by @SergeyRyabinin in (#401)
  * Update aws-c-io for Windows heap access violation
    fix by @TwistedTwigleg in (#400)
* Tue Sep  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.18.3
  * Use latest versions of S2N-TLS and AWS-LC by @graebm in (#397)
  * Adds support for Anonymous credentials by @waahm7 in (#398)
- from version 0.18.2
  * Fix script that keeps AWS_CRT_CPP_VERSION up
    to date by @graebm in (#394)
- from version 0.18.1
  * Fix to cmake detection of CRT version by
    consumers by @sdavtaker in (#393)
- from version 0.18.0
  * Latest submodules by @TingDaoK in (#392)
- Refresh patches for new version
  * acc_fix-cmake-modules-path.patch
* Mon Aug  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.17.34
  * Support/DELAYLOAD DLLs by @graebm in (#387)
- from version 0.17.33
  * Fixes an mqtt client issue where calling disconnect
    did not properly clean up some session state
- from version 0.17.32
  * Fixes an issue where the eventstream client would close the
    connection if it received data from an old stream. There is
    no mechanism to ensure there is no inbound data in transit
    at the time it closes its end of a stream, so the client
    instead ignores stale messages.
- from version 0.17.31
  * Update io and eventstream submodules to pull in crash
    and stream id ordering fixes
- from version 0.17.30
  * Document building for Apple silicon (M1). by @graebm in (#375)
  * MQTT builder custom authorizer support by @TwistedTwigleg in (#374)
* Thu May 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.17.29
  * Adapt new input stream api by @TingDaoK in (#341)
  * Update aws-c-common to latest release by @TwistedTwigleg in (#372)
- Drop patches for issue fixed upstream
  * acc_adapt-new-input-stream-api.patch
* Fri Apr 29 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.17.28
